"""abstractvision: Generative vision capabilities for abstractcore.ai."""

__version__ = "0.1.0"
__author__ = "Laurent-Philippe Albou"
__email__ = "contact@abstractcore.ai"

# Core exports will be added as the project develops
